.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

chunked_array
=============

Defined in ``xtensor/xchunked_array.hpp``

.. doxygenfunction:: xt::chunked_array
   :project: xtensor
